@@ -7,16 +7,17 @@
 
 sendxy <- function(plot.call,
                    x, y, 
-                   xy.lbls = NA,
+                   xy.lbls = NA, x.lbls = NA,y.lbls=NA,
                    xlim = NA,
                    ylim = NA,
                    mai=NA,
+                   mai.prc=FALSE,
                    plt.extras=NA,
                    bound.pt=TRUE,source.plot=NA,
                    paint=TRUE,img.prog = NA,
                    resize="800x1100",
                    ps.paper="letter",ps.width=8,ps.height=11,
-                   fname.root="test",dir="./",
+                   fname.root="test",dir="./",header="v2",
                    up.left=c(205,131),low.right=c(633,883),
                    spot.radius=10
                    ){
@@ -57,7 +58,7 @@ sendxy <- function(plot.call,
     plt.extras$plot1 = plt
   }
   # run sendplot using default or set arguments
-  sendplot(mat = mat, plot.calls = plot.calls, mai.mat = mai.mat , type="scatterplot",x = x, y = y, xlim = xlim, ylim = ylim, plt.extras=plt.extras, xy.lbls = xy.lbls,bound.pt=bound.pt,resize=resize, ps.paper=ps.paper,ps.width=ps.width,ps.height=ps.height,fname.root=fname.root,dir=dir, paint=paint,source.plot=source.plot, img.prog=img.prog,up.left=up.left,low.right=low.right,spot.radius=spot.radius)
+  sendplot(mat = mat, plot.calls = plot.calls, mai.mat = mai.mat ,mai.prc=mai.prc, type="scatterplot",x = x, y = y, xlim = xlim, ylim = ylim, plt.extras=plt.extras, xy.lbls = xy.lbls,x.lbls = x.lbls,y.lbls=y.lbls,bound.pt=bound.pt,resize=resize, ps.paper=ps.paper,ps.width=ps.width,ps.height=ps.height,fname.root=fname.root,dir=dir, paint=paint,source.plot=source.plot, img.prog=img.prog,up.left=up.left,low.right=low.right,spot.radius=spot.radius, header=header)
 
   
 }# end sendxy
